@@ -20,3 +20,14 @@ def fake_pastaporto_token_for_user(
         secret,
         algorithm="HS256",
     )
+
+def fake_service_to_service_token(secret: str, *, issuer: str, audience: str):
+    return jwt.encode(
+        {
+            'iss': issuer,
+            'aud': audience,
+            "exp": datetime.now() + datetime.timedelta(minutes=1),
+        },
+        secret,
+        algorithm="HS256",
+    )
